@@ -118,14 +118,15 @@ class Client:
         if "id" not in result and resource_id is not None:
             result["id"] = resource_id
 
-        if "type" in result:
-            if result["type"] in self.objects_types:
-                object_class = self.objects_types[result["type"]]
-            else:
-                # in case any new types are introduced by the API
-                object_class = Resource
+        if "type" in result and result["type"] in self.objects_types:
+            object_class = self.objects_types[result["type"]]
+        elif "type" in result or not resource_type and "id" in result:
+            # in case any new types are introduced by the API
+            object_class = Resource
         elif resource_type:
             object_class = resource_type
+        elif item.get("results") is True:
+            return True
         else:
             raise DeezerUnknownResource(f"Unable to find resource type for {result!r}")
         assert object_class is not None  # nosec B101
@@ -166,7 +167,7 @@ class Client:
         json_data = response.json()
         if not isinstance(json_data, dict):
             return json_data
-        if "error" in json_data:
+        if "error" in json_data and json_data["error"]:
             raise DeezerErrorResponse(json_data)
         return self._process_json(
             json_data,
@@ -541,6 +542,45 @@ class Client:
         """
         return self.request("DELETE", "user/me/tracks", track_id=track_id)
 
+    def remove_user_playlist(self, playlist_id: int) -> bool:
+        """
+        Remove a playlist from the user's library
+
+        :param playlist_id: the ID of the playlist to remove.
+        :return: boolean whether the operation succeeded.
+        """
+        return self.request("DELETE", "user/me/playlists", playlist_id=playlist_id)
+
+    def add_user_playlist(self, playlist_id: int) -> bool:
+        """
+        Add a playlist to the user's library
+
+        :param playlist_id: the ID of the playlist to add.
+        :return: boolean whether the operation succeeded.
+        """
+        return self.request("POST", "user/me/playlists", playlist_id=playlist_id)
+
+    def create_playlist(self, playlist_name) -> int:
+        """
+        Create a playlist on the user's account
+
+        :param playlist_name: the name of the playlist.
+        :return: the ID of the playlist that was created
+        """
+        result = self.request("POST", "user/me/playlists", title=playlist_name)
+        # Note: the REST API call returns a dict with just the "id" key in it,
+        # so we return that instead of the full Playlist object
+        return result.id
+
+    def delete_playlist(self, playlist_id) -> bool:
+        """
+        Delete a playlist from the user's account
+
+        :param playlist_id: the ID of the playlist to remove.
+        :return: boolean whether the operation succeeded.
+        """
+        return self.request("DELETE", f"playlist/{playlist_id}")
+
     def _search(
         self,
         path: str,
